@@ -1,7 +1,5 @@
 '''
-Created on Jun 7, 2013
-
-@author: Steven
+Deals with cosmological parameters in a nice way.
 '''
 import numpy as _np
 
@@ -77,7 +75,7 @@ class Cosmology(object):
     """
     # A dictionary of bounds for each parameter
     # This also forms a list of all parameters possible
-    bounds = {"sigma_8":[0.1, 10],
+    _bounds = {"sigma_8":[0.1, 10],
               "n":[-3, 4],
               "w":[-1.5, 0],
               "cs2_lam":[-1, 2],
@@ -114,7 +112,7 @@ class Cosmology(object):
         # Check values in kwargs
         #=======================================================================
         for k in kwargs:
-            if k not in Cosmology.bounds:
+            if k not in Cosmology._bounds:
                 raise ValueError(k + " is not a valid parameter for Cosmology")
 
         #=======================================================================
@@ -186,7 +184,7 @@ class Cosmology(object):
             self.omegam = self.omegab + self.omegac
 
         else:
-            raise AttributeError("your input omegaXXX arguments were invalid")
+            raise AttributeError("your input omegaXXX arguments were invalid" + str(kwargs))
 
         if hasattr(self, "omegam"):
             self.mean_dens = self.crit_dens * self.omegam
@@ -200,7 +198,7 @@ class Cosmology(object):
                 self.omegak = 1 - self.omegav - self.omegam
 
         # Check all their values
-        for k, v in Cosmology.bounds.iteritems():
+        for k, v in Cosmology._bounds.iteritems():
             if k in self.__dict__:
                 self._check_bounds(k, v[0], v[1])
 
@@ -257,7 +255,8 @@ class Cosmology(object):
                "omegam":"omega_M_0",
                "n":"n",
                "omegan":"omega_n_0",
-               "N_nu_massive":"N_nu"}
+               "N_nu_massive":"N_nu",
+               "w":"w"}
         return_dict = {}
         for k, v in self.__dict__.iteritems():
             if k in map:
