@@ -5,7 +5,7 @@ The module contains a single class, `Perturbations`, which wraps almost all the
 functionality of `hmf` in an easy-to-use way.
 '''
 
-version = '1.2.2'
+version = '1.3.0'
 
 ###############################################################################
 # Some Imports
@@ -18,7 +18,8 @@ import copy
 
 # from scitools.std import sin,cos,tan,abs,arctan,arccos,arcsin #Must be in this form to work for some reason.
 from cosmolopy import distance as cd
-import cosmography
+from cosmolopy import density as cden
+# import cosmography
 from cosmo import Cosmology
 import tools
 from fitting_functions import Fits
@@ -212,7 +213,6 @@ class Perturbations(object):
 
         # Set up a simple dictionary of kwargs which can be later updated
         self._cpdict = {k:v for k, v in kwargs.iteritems() if k in self._cp}
-
         if M is None:
             M = np.linspace(10, 15, 501)
 
@@ -242,11 +242,6 @@ class Perturbations(object):
         self.nz = nz
         self.cosmo_params = Cosmology(default="planck1_base", **self._cpdict)
 
-        # Now update them all
-#         self.update(M=M, mf_fit=mf_fit, k_bounds=k_bounds, transfer_file=transfer_file, wdm_mass=wdm_mass,
-#                      delta_halo=delta_halo, delta_wrt=delta_wrt, user_fit=user_fit, z=z,
-#                      transfer_fit=transfer_fit, cut_fit=cut_fit, z2=z2, nz=nz, ** kwargs)
-
     def update(self, **kwargs):
         """
         Update the class with the given arguments in an optimal manner.
@@ -266,14 +261,12 @@ class Perturbations(object):
                         true_cp[k] = v
 
             self._cpdict.update(true_cp)
-
             # Delete the entries we've used from kwargs
             for k in cp:
                 del kwargs[k]
 
             # Now actually update the Cosmology class
             self.cosmo_params = Cosmology(default="planck1_base", **self._cpdict)
-
             if "n" in true_cp:
                 del self._unnormalized_power
             if "sigma_8" in true_cp:
@@ -281,42 +274,9 @@ class Perturbations(object):
             if "delta_c" in true_cp:
                 del self.fsigma
 
-            if "omegab" in true_cp:
-                del self._transfer_original
-                del self._power_cdm_0
-                del self._sigma_0
-                del self._dlnsdlnm
-                del self.dndm
-            if "omegac" in true_cp:
-                del self._transfer_original
-                del self._power_cdm_0
-                del self._power_0
-                del self._sigma_0
-                del self._dlnsdlnm
-                del self.dndm
-            if "h" in cp or "H0" in true_cp:
-                del self._transfer_original
-                del self._power_0
-                if "omegab" not in self._cpdict:
-                    del self.camb_params
-                    del self._power_cdm_0
-                    del self._power_0
-                    del self._sigma_0
-                    del self._dlnsdlnm
-                    del self.dndm
-            if "omegab_h2" in true_cp:
-                del self._transfer_original
-                del self._power_cdm_0
-                del self._sigma_0
-                del self._dlnsdlnm
-                del self.dndm
-            if "omegac_h2" in true_cp:
-                del self._transfer_original
-                del self._power_cdm_0
-                del self._power_0
-                del self._sigma_0
-                del self._dlnsdlnm
-                del self.dndm
+            for item in ["omegab", "omegac", "h", "H0", "omegab_h2", "omegac_h2"]:
+                if item in true_cp:
+                    del self._transfer_original
 
         # Now do rest of the parameters
         for key, val in kwargs.iteritems():
@@ -394,10 +354,6 @@ class Perturbations(object):
 
         # Delete stuff dependent on it
         del self._sigma_0
-        del self._dlnsdlnm
-        del self.dndm
-        del self.dndlnm
-        del self.dndlog10m
 
         self.__M = 10 ** val
 
@@ -658,9 +614,7 @@ class Perturbations(object):
                 self.__delta_halo = self._delta_halo_base
 
             elif self.delta_wrt == 'crit':
-                self.__delta_halo = self._delta_halo_base / cosmography.omegam_z(self.z, self.cosmo_params.omegam,
-                                                                                 self.cosmo_params.omegav,
-                                                                                 self.cosmo_params.omegak)
+                self.__delta_halo = self._delta_halo_base / cden.omega_M_z(self.z, **self.cosmo_params.cosmolopy_dict())
             return self.__delta_halo
 
     @delta_halo.deleter
@@ -689,7 +643,7 @@ class Perturbations(object):
         """
         try:
             return self.__transfer_original
-        except:
+        except AttributeError:
             self.__transfer_original = tools.get_transfer(self._transfer_file, self.cosmo_params,
                                                           self.transfer_fit, self._camb_options,
                                                           self.k_bounds)
@@ -731,10 +685,9 @@ class Perturbations(object):
         try:
             return self.__lnk
         except:
-            if self.transfer_fit == "CAMB":
-                self.__lnk, dlnk = tools.new_k_grid(self._transfer_original[0, :], self.k_bounds)
-            elif self.transfer_fit == "EH":
-                self.__lnk = self._transfer_original[0, :]
+            self.__lnk, dlnk = np.linspace(np.log(self.k_bounds[0]),
+                                           np.log(self.k_bounds[1]),
+                                           250, retstep=True)
 
             # CHECK KR_BOUNDS
             self.max_error, self.min_error = tools.check_kr(self.M[0], self.M[-1], self.cosmo_params.mean_dens,
@@ -751,12 +704,7 @@ class Perturbations(object):
     def lnk(self):
         try:
             del self.__lnk
-
             del self._unnormalized_power
-            del self._power_cdm_0
-            del self._power_0
-            del self._sigma_0
-            del self._dlnsdlnm
         except:
             pass
 
@@ -780,7 +728,6 @@ class Perturbations(object):
     def _unnormalized_power(self):
         try:
             del self.__unnormalized_power
-
             del self._power_cdm_0
         except:
             pass
@@ -828,7 +775,6 @@ class Perturbations(object):
         try:
             del self.__power_0
             del self._sigma_0
-            del self._dlnsdlnm
             del self.power
         except:
             pass
@@ -910,9 +856,7 @@ class Perturbations(object):
             return self.__growth
         except:
             if self.z > 0:
-                self.__growth = cosmography.growth_factor(self.z, self.cosmo_params.omegam,
-                                                          self.cosmo_params.omegak,
-                                                          self.cosmo_params.omegav)
+                self.__growth = tools.growth_factor(self.z, self.cosmo_params)
             else:
                 self.__growth = 1
             return self.__growth
@@ -1213,7 +1157,7 @@ class Perturbations(object):
             int_upper = 0
 
         # Calculate the cumulative integral (backwards) of mass_function (Adding on the upper integral)
-        ngtm = intg.cumtrapz(mass_function[::-1], dx=np.log(M[1]) - np.log(M[0]), initial=0)[::-1] + int_upper
+        ngtm = np.concatenate((intg.cumtrapz(mass_function[::-1], dx=np.log(M[1]) - np.log(M[0]))[::-1], np.zeros(1))) + int_upper
 
         # We need to set ngtm back in the original length vector with nans where they were originally
         if len(ngtm) < len(self.M):
@@ -1262,7 +1206,7 @@ class Perturbations(object):
                 int_upper = 0
 
             # Calculate the cumulative integral (backwards) of mass_function (Adding on the upper integral)
-            self.__mgtm = intg.cumtrapz(mass_function[::-1] * M[::-1], dx=np.log(M[1]) - np.log(M[0]), initial=0)[::-1] + int_upper
+            self.__mgtm = np.concatenate((intg.cumtrapz(mass_function[::-1] * M[::-1], dx=np.log(M[1]) - np.log(M[0]))[::-1], np.zeros(1))) + int_upper
 
             # We need to set ngtm back in the original length vector with nans where they were originally
             if len(self.__mgtm) < len(self.M):
@@ -1300,7 +1244,7 @@ class Perturbations(object):
 
             print "INT LOWER = ", int_lower
             # Calculate the cumulative integral of mass_function (Adding on the lower integral)
-            self.__nltm = intg.cumtrapz(mass_function, dx=np.log(M[1]) - np.log(M[0]), initial=0) + int_lower
+            self.__nltm = np.concatenate((intg.cumtrapz(mass_function, dx=np.log(M[1]) - np.log(M[0])), np.zeros(1))) + int_lower
 
             # We need to set ngtm back in the original length vector with nans where they were originally
             if len(self.__nltm) < len(self.M):
@@ -1338,7 +1282,7 @@ class Perturbations(object):
                 int_lower = 0
 
             # Calculate the cumulative integral of mass_function (Adding on the upper integral)
-            self.__mltm = intg.cumtrapz(mass_function * M, dx=np.log(M[1]) - np.log(M[0]), initial=0) + int_lower
+            self.__mltm = np.concatenate((intg.cumtrapz(mass_function * M, dx=np.log(M[1]) - np.log(M[0])), np.zeros(1))) + int_lower
 
             # We need to set ngtm back in the original length vector with nans where they were originally
             if len(self.__mltm) < len(self.M):
